@@ -43,6 +43,7 @@ def build_model(model_name):
 		'DeepID': DeepID.loadModel,
 		'Dlib': DlibWrapper.loadModel,
 		'ArcFace': ArcFace.loadModel,
+
 		'Emotion': Emotion.loadModel,
 		'Age': Age.loadModel,
 		'Gender': Gender.loadModel,
@@ -58,7 +59,7 @@ def build_model(model_name):
 	else:
 		raise ValueError('Invalid model_name passed - {}'.format(model_name))
 
-def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'mtcnn'):
+def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'mtcnn', align = True):
 
 	"""
 	This function verifies an image pair is same person or different persons.
@@ -152,11 +153,13 @@ def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric =
 				#img_path, model_name = 'VGG-Face', model = None, enforce_detection = True, detector_backend = 'mtcnn'
 				img1_representation = represent(img_path = img1_path
 						, model_name = model_name, model = custom_model
-						, enforce_detection = enforce_detection, detector_backend = detector_backend)
+						, enforce_detection = enforce_detection, detector_backend = detector_backend
+						, align = align)
 
 				img2_representation = represent(img_path = img2_path
 						, model_name = model_name, model = custom_model
-						, enforce_detection = enforce_detection, detector_backend = detector_backend)
+						, enforce_detection = enforce_detection, detector_backend = detector_backend
+						, align = align)
 
 				#----------------------
 				#find distances between embeddings
@@ -457,7 +460,7 @@ def analyze(img_path, actions = ['emotion', 'age', 'gender', 'race'] , models =
 
 		return resp_obj
 
-def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'mtcnn'):
+def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'mtcnn', align = True):
 
 	"""
 	This function applies verification several times and find an identity in a database
@@ -568,7 +571,8 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 
 					representation = represent(img_path = employee
 						, model_name = model_name, model = custom_model
-						, enforce_detection = enforce_detection, detector_backend = detector_backend)
+						, enforce_detection = enforce_detection, detector_backend = detector_backend
+						, align = align)
 
 					instance.append(representation)
 
@@ -609,7 +613,8 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 
 				target_representation = represent(img_path = img_path
 					, model_name = model_name, model = custom_model
-					, enforce_detection = enforce_detection, detector_backend =detector_backend)
+					, enforce_detection = enforce_detection, detector_backend = detector_backend
+					, align = align)
 
 				for k in metric_names:
 					distances = []
@@ -700,7 +705,7 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 
 	return None
 
-def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection = True, detector_backend = 'mtcnn'):
+def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection = True, detector_backend = 'mtcnn', align = True):
 
 	"""
 	This function represents facial images as vectors.
@@ -725,6 +730,8 @@ def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection
 	if model is None:
 		model = build_model(model_name)
 
+	functions.initialize_detector(detector_backend = detector_backend)
+
 	#---------------------------------
 
 	#decide input shape
@@ -734,7 +741,8 @@ def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection
 	img = functions.preprocess_face(img = img_path
 		, target_size=(input_shape_y, input_shape_x)
 		, enforce_detection = enforce_detection
-		, detector_backend = detector_backend)
+		, detector_backend = detector_backend
+		, align = align)
 
 	#represent
 	embedding = model.predict(img)[0].tolist()
@@ -774,7 +782,7 @@ def stream(db_path = '', model_name ='VGG-Face', distance_metric = 'cosine', ena
 	realtime.analysis(db_path, model_name, distance_metric, enable_face_analysis
 						, source = source, time_threshold = time_threshold, frame_threshold = frame_threshold)
 
-def detectFace(img_path, detector_backend = 'mtcnn'):
+def detectFace(img_path, detector_backend = 'mtcnn', enforce_detection = True):
 
 	"""
 	This function applies pre-processing stages of a face recognition pipeline including detection and alignment
@@ -790,7 +798,8 @@ def detectFace(img_path, detector_backend = 'mtcnn'):
 
 	functions.initialize_detector(detector_backend = detector_backend)
 
-	img = functions.preprocess_face(img = img_path, detector_backend = detector_backend)[0] #preprocess_face returns (1, 224, 224, 3)
+	img = functions.preprocess_face(img = img_path, detector_backend = detector_backend
+		, enforce_detection = enforce_detection)[0] #preprocess_face returns (1, 224, 224, 3)
 	return img[:, :, ::-1] #bgr to rgb
 
 #---------------------------
