@@ -1,11 +1,12 @@
 import os
 from pathlib import Path
 import gdown
-import keras
-from keras.models import Model
-from keras.layers import Conv2D, Activation, Input, Add, MaxPooling2D, Flatten, Dense, Dropout
 import zipfile
 
+from tensorflow import keras
+from tensorflow.keras.models import Model
+from tensorflow.keras.layers import Conv2D, Activation, Input, Add, MaxPooling2D, Flatten, Dense, Dropout
+
 #-------------------------------------
 
 def loadModel(url = 'https://drive.google.com/uc?id=1uRLtBCTQQAvHJ_KVrdbRJiCKxU8m5q2J'):
@@ -14,15 +15,15 @@ def loadModel(url = 'https://drive.google.com/uc?id=1uRLtBCTQQAvHJ_KVrdbRJiCKxU8
 	
 	x = Conv2D(20, (4, 4), name='Conv1', activation='relu', input_shape=(55, 47, 3))(myInput)
 	x = MaxPooling2D(pool_size=2, strides=2, name='Pool1')(x)
-	x = Dropout(rate=1, name='D1')(x)
+	x = Dropout(rate=0.99, name='D1')(x)
 	
 	x = Conv2D(40, (3, 3), name='Conv2', activation='relu')(x)
 	x = MaxPooling2D(pool_size=2, strides=2, name='Pool2')(x)
-	x = Dropout(rate=1, name='D2')(x)
+	x = Dropout(rate=0.99, name='D2')(x)
 	
 	x = Conv2D(60, (3, 3), name='Conv3', activation='relu')(x)
 	x = MaxPooling2D(pool_size=2, strides=2, name='Pool3')(x)
-	x = Dropout(rate=1, name='D3')(x)
+	x = Dropout(rate=0.99, name='D3')(x)
 	
 	x1 = Flatten()(x)
 	fc11 = Dense(160, name = 'fc11')(x1)
